@@ -1,8 +1,6 @@
 """Init."""
 
-import importlib_metadata
-
-from . import argparse_tools, data_safety_tools, logging_tools
+from . import argparse_tools, data_safety_tools, logging_tools, timing_tools
 from .enviro_tools import from_environment, from_environment_as_dataclass  # noqa
 from .setup_tools import SetupShop  # noqa
 from .strtobool import strtobool
@@ -15,10 +13,12 @@ __all__ = [
     "strtobool",
     "argparse_tools",
     "data_safety_tools",
+    "timing_tools",
+    "prometheus_tools"
 ]
 
 # version is a human-readable version number.
-__version__ = importlib_metadata.version(__package__ or __name__)
+__version__ = "1.15.0"
 
 
 # version_info is a four-tuple for programmatic comparison. The first
